<h5>Multi-threaded Python Port Scanner for use on Linux or Windows</h5>
<br>
-----------------------------------------------------------------------
<br>
Threader3000 is a script written in Python3 that allows multi-threaded port scanning. 
The program is interactive and simply requires you to run it to begin. Once started, 
you will be asked to input an IP address or a FQDN as Threader3000 does resolve hostnames. 
A full port scan should take three minutes or less depending on your internet connection.
<br>
Check me out on Twitter @joehelle, Twitch at https://twitch.tv/themayor11/, on Github at 
https://github.com/dievus, or visit my cybersec Discord at https://discord.gg/DW4Q4pp.
